# Welcome to the New Home of SAP LeanIX Documentation
### On this page
  * [Choose a Language](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal#choose-a-language)
  * [Search in Your Preferred Language](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal#search-in-your-preferred-language)
  * [Download PDF Files](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal#download-pdf-files)
  * [Browse Topics](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal#browse-topics)
  * [Share Your Feedback](https://help.sap.com/docs/leanix/ea/documentation-on-sap-help-portal#share-your-feedback)


We’re excited to announce that as of June 30, 2025, the SAP LeanIX documentation has officially moved to SAP Help Portal! This change brings a more streamlined and user-friendly experience, with enhanced features like multilingual support, PDF downloads, and an intuitive navigation.
This quick start guide will help you get the most out of the new documentation platform.
